package com.example.tdl.web;

import com.example.tdl.domain.dto.CommFeedback;
import com.example.tdl.domain.vo.AlarmLogVo;
import com.example.tdl.domain.vo.HomePageDataVo;
import com.example.tdl.domain.vo.ResultRouteVo;
import com.example.tdl.domain.vo.TermVo;
import com.example.tdl.service.AlarmLogServcie;
import com.example.tdl.service.RouteService;
import com.google.gson.Gson;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/homePage")
public class HomePageController {
    private Logger logger = LoggerFactory.getLogger(HomePageController.class);

    Gson gson = new Gson();

    CommFeedback fb = new CommFeedback();

    @Autowired
    private RouteService routeService;

    @Autowired
    private AlarmLogServcie alarmLogServcie;

    //获取当天所有的设备数据
    @ApiOperation(value = "获取所有的运输数据",notes = "获取运输设备数据：" +
            "sum:总数量" +
            "onRoute:在途数量" +
            "complted:已完成数量" +
            "alarmed: 报警数量" +
            "routeVoList: " +
                "routeNumber:路由编号（R+TyyyyMMdd+运输方式+四位随机数）"+
                "routeName:路由名称（出发地-启运地）"+
                "abbreviation:名称缩写（出发地-启运地-运输方式）"+
                "startLongitude:启运经度"+
                "startLatitude:启运纬度"+
                "startCounrty:启运国"+
                "startProvince:启运省"+
                "startCity:启运市"+
                "startAddress:启运地址"+
                "endLongitude:目的经度"+
                "endLatitude:目的纬度"+
                "endCounrty:目的国"+
                "endProvince:目的省"+
                "endCity:目的市"+
                "endAddress:目的地址"+
                "transport:运输方式（T铁路，G汽运，H海运，K空运，D快递）"+
                "transportRemark:运输方式备注"+
                "remark:备注" +
            "alarmLogVoList :"+
                "routeName:线路名称"+
                "description:报警描述" +
                "data:数据"+
                "alarmTime:报警时间")
    @GetMapping("/getAll")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getAll(){
        HomePageDataVo dataVo = new HomePageDataVo();
        //获取所有的路线
        List<ResultRouteVo> routeVos = routeService.getAll();//所有的路线
        //List<ResultRouteVo> routeVoList =  routeService.getAllRoute();//当天的数量
        //获取所有的报警
        List<AlarmLogVo> alarmLogVos = alarmLogServcie.getAll();
        // 获取所有的路线数量
        dataVo.setRouteVoList(routeVos);//路线列表
        dataVo.setAlarmLogVoList(alarmLogVos);//报警列表
        dataVo.setSum(routeVos.size());//总数量
        dataVo.setOnRoute(0);//在途数量
        dataVo.setComplted(0);//已完成数量
        dataVo.setAlarmed(0);//报警数量
        return gson.toJson(dataVo);
    }


    //根据条件获取路线数据(所有的)
    @PostMapping("/getByTerm")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getByTerm(@RequestBody TermVo termVo){
        HomePageDataVo dataVo = new HomePageDataVo();
        List<ResultRouteVo> routeVos = routeService.getAll();//所有的路线
//        List<ResultRouteVo> routeVoList =  routeService.getAllRoute(termVo.getTime());//根据条件获取数据
        List<AlarmLogVo> alarmLogVos = alarmLogServcie.getAlarmLog(termVo.getTime());
        dataVo.setRouteVoList(routeVos);//路线列表
        dataVo.setAlarmLogVoList(alarmLogVos);//报警列表
        dataVo.setSum(routeVos.size());//总数量
        dataVo.setOnRoute(0);//在途数量
        dataVo.setComplted(0);//已完成数量
        dataVo.setAlarmed(0);//报警数量
        return gson.toJson(dataVo);
    }

}
